==> pychord-1.1.0.tar.gz: pychord-1.1.0/pychord/constants/qualities.py <==
# Do not import DEFAULT_QUALITIES directly
# Use QualityManager instead
DEFAULT_QUALITIES = [
    # chords consist of 2 notes
    ('5', (0, 7)),
    ('no5', (0, 4)),
    ('omit5', (0, 4)),
    ('m(no5)', (0, 3)),
    ('m(omit5)', (0, 3)),
    # 3 notes
    ('', (0, 4, 7)),
    ('maj', (0, 4, 7)),
    ('m', (0, 3, 7)),
    ('min', (0, 3, 7)),
    ('-', (0, 3, 7)),
    ('dim', (0, 3, 6)),
    # Not to confuse Ab5 with A(b5)
    ('(b5)', (0, 4, 6)),
    ('aug', (0, 4, 8)),
    ('sus2', (0, 2, 7)),
    ('sus4', (0, 5, 7)),
    ('sus', (0, 5, 7)),
    # 4 notes
    ('6', (0, 4, 7, 9)),
    ('7', (0, 4, 7, 10)),
    ('7-5', (0, 4, 6, 10)),
    ('7b5', (0, 4, 6, 10)),
    ('7+5', (0, 4, 8, 10)),
    ('7#5', (0, 4, 8, 10)),
    ('7sus4', (0, 5, 7, 10)),
    ('m6', (0, 3, 7, 9)),
    ('m7', (0, 3, 7, 10)),
    ('m7-5', (0, 3, 6, 10)),
    ('m7b5', (0, 3, 6, 10)),
    ('m7+5', (0, 3, 8, 10)),
    ('m7#5', (0, 3, 8, 10)),
    ('dim6', (0, 3, 6, 8)),
    ('dim7', (0, 3, 6, 9)),
    ('M7', (0, 4, 7, 11)),
    ('maj7', (0, 4, 7, 11)),
    ('M7+5', (0, 4, 8, 11)),
    ('mM7', (0, 3, 7, 11)),
    ('add4', (0, 4, 5, 7)),
    ('Madd4', (0, 4, 5, 7)),
    ('madd4', (0, 3, 5, 7)),
    ('add9', (0, 4, 7, 14)),
    ('Madd9', (0, 4, 7, 14)),
    ('madd9', (0, 3, 7, 14)),
    ('sus4add9', (0, 5, 7, 14)),
    ('sus4add2', (0, 2, 5, 7)),
    ('2', (0, 4, 7, 14)),
    ('add11', (0, 4, 7, 17)),
    ('4', (0, 4, 7, 17)),
    # 5 notes
    ('m69', (0, 3, 7, 9, 14)),
    ('69', (0, 4, 7, 9, 14)),
    ('9', (0, 4, 7, 10, 14)),
    ('m9', (0, 3, 7, 10, 14)),
    ('M9', (0, 4, 7, 11, 14)),
    ('maj9', (0, 4, 7, 11, 14)),
    ('9sus4', (0, 5, 7, 10, 14)),
    ('7-9', (0, 4, 7, 10, 13)),
    ('7b9', (0, 4, 7, 10, 13)),
    ('7+9', (0, 4, 7, 10, 15)),
    ('7#9', (0, 4, 7, 10, 15)),
    ('9-5', (0, 4, 6, 10, 14)),
    ('9b5', (0, 4, 6, 10, 14)),
    ('9+5', (0, 4, 8, 10, 14)),
    ('9#5', (0, 4, 8, 10, 14)),
    ('7#9b5', (0, 4, 6, 10, 15)),
    ('7#9#5', (0, 4, 8, 10, 15)),
    ('m7b9b5', (0, 3, 6, 10, 13)),
    ('7b9b5', (0, 4, 6, 10, 13)),
    ('7b9#5', (0, 4, 8, 10, 13)),
    ('11', (0, 7, 10, 14, 17)),
    ('7+11', (0, 4, 7, 10, 18)),
    ('7#11', (0, 4, 7, 10, 18)),
    ('M7+11', (0, 4, 7, 11, 18)),
    ('M7#11', (0, 4, 7, 11, 18)),
    ('7b9#9', (0, 4, 7, 10, 13, 15)),
    ('7b9#11', (0, 4, 7, 10, 13, 18)),
    ('7#9#11', (0, 4, 7, 10, 15, 18)),
    ('7-13', (0, 4, 7, 10, 20)),
    ('7b13', (0, 4, 7, 10, 20)),
    ('m7add11', (0, 3, 7, 10, 17)),
    ('M7add11', (0, 4, 7, 11, 17)),
    ('mM7add11', (0, 3, 7, 11, 17)),
    # 6 notes
    ('7b9b13', (0, 4, 7, 10, 13, 17, 20)),
    ('9+11', (0, 4, 7, 10, 14, 18)),
    ('9#11', (0, 4, 7, 10, 14, 18)),
    ('13', (0, 4, 7, 10, 14, 21)),
    ('13-9', (0, 4, 7, 10, 13, 21)),
    ('13b9', (0, 4, 7, 10, 13, 21)),
    ('13+9', (0, 4, 7, 10, 15, 21)),
    ('13#9', (0, 4, 7, 10, 15, 21)),
    ('13+11', (0, 4, 7, 10, 18, 21)),
    ('13#11', (0, 4, 7, 10, 18, 21)),
    ('M7add13', (0, 4, 7, 9, 11, 14))
]

==> pychord-1.1.1.tar.gz: pychord-1.1.1/pychord/constants/qualities.py <==
# Do not import DEFAULT_QUALITIES directly
# Use QualityManager instead
DEFAULT_QUALITIES = [
    # chords consist of 2 notes
    ('5', (0, 7)),
    ('no5', (0, 4)),
    ('omit5', (0, 4)),
    ('m(no5)', (0, 3)),
    ('m(omit5)', (0, 3)),
    # 3 notes
    ('', (0, 4, 7)),
    ('maj', (0, 4, 7)),
    ('m', (0, 3, 7)),
    ('min', (0, 3, 7)),
    ('-', (0, 3, 7)),
    ('dim', (0, 3, 6)),
    # Not to confuse Ab5 with A(b5)
    ('(b5)', (0, 4, 6)),
    ('aug', (0, 4, 8)),
    ('sus2', (0, 2, 7)),
    ('sus4', (0, 5, 7)),
    ('sus', (0, 5, 7)),
    # 4 notes
    ('6', (0, 4, 7, 9)),
    ('7', (0, 4, 7, 10)),
    ('7-5', (0, 4, 6, 10)),
    ('7b5', (0, 4, 6, 10)),
    ('7+5', (0, 4, 8, 10)),
    ('7#5', (0, 4, 8, 10)),
    ('7sus4', (0, 5, 7, 10)),
    ('m6', (0, 3, 7, 9)),
    ('m7', (0, 3, 7, 10)),
    ('m7-5', (0, 3, 6, 10)),
    ('m7b5', (0, 3, 6, 10)),
    ('m7+5', (0, 3, 8, 10)),
    ('m7#5', (0, 3, 8, 10)),
    ('dim6', (0, 3, 6, 8)),
    ('dim7', (0, 3, 6, 9)),
    ('M7', (0, 4, 7, 11)),
    ('maj7', (0, 4, 7, 11)),
    ('M7+5', (0, 4, 8, 11)),
    ('mM7', (0, 3, 7, 11)),
    ('add4', (0, 4, 5, 7)),
    ('Madd4', (0, 4, 5, 7)),
    ('madd4', (0, 3, 5, 7)),
    ('add9', (0, 4, 7, 14)),
    ('Madd9', (0, 4, 7, 14)),
    ('madd9', (0, 3, 7, 14)),
    ('sus4add9', (0, 5, 7, 14)),
    ('sus4add2', (0, 2, 5, 7)),
    ('2', (0, 4, 7, 14)),
    ('add11', (0, 4, 7, 17)),
    ('4', (0, 4, 7, 17)),
    # 5 notes
    ('m69', (0, 3, 7, 9, 14)),
    ('69', (0, 4, 7, 9, 14)),
    ('9', (0, 4, 7, 10, 14)),
    ('m9', (0, 3, 7, 10, 14)),
    ('M9', (0, 4, 7, 11, 14)),
    ('maj9', (0, 4, 7, 11, 14)),
    ('9sus4', (0, 5, 7, 10, 14)),
    ('7-9', (0, 4, 7, 10, 13)),
    ('7b9', (0, 4, 7, 10, 13)),
    ('7+9', (0, 4, 7, 10, 15)),
    ('7#9', (0, 4, 7, 10, 15)),
    ('9-5', (0, 4, 6, 10, 14)),
    ('9b5', (0, 4, 6, 10, 14)),
    ('9+5', (0, 4, 8, 10, 14)),
    ('9#5', (0, 4, 8, 10, 14)),
    ('7#9b5', (0, 4, 6, 10, 15)),
    ('7#9#5', (0, 4, 8, 10, 15)),
    ('m7b9b5', (0, 3, 6, 10, 13)),
    ('7b9b5', (0, 4, 6, 10, 13)),
    ('7b9#5', (0, 4, 8, 10, 13)),
    ('11', (0, 7, 10, 14, 17)),
    ('7+11', (0, 4, 7, 10, 18)),
    ('7#11', (0, 4, 7, 10, 18)),
    ('M7+11', (0, 4, 7, 11, 18)),
    ('M7#11', (0, 4, 7, 11, 18)),
    ('7b9#9', (0, 4, 7, 10, 13, 15)),
    ('7b9#11', (0, 4, 7, 10, 13, 18)),
    ('7#9#11', (0, 4, 7, 10, 15, 18)),
    ('7-13', (0, 4, 7, 10, 20)),
    ('7b13', (0, 4, 7, 10, 20)),
    ('m7add11', (0, 3, 7, 10, 17)),
    ('M7add11', (0, 4, 7, 11, 17)),
    ('mM7add11', (0, 3, 7, 11, 17)),
    # 6 notes
    ('7b9b13', (0, 4, 7, 10, 13, 17, 20)),
    ('9+11', (0, 4, 7, 10, 14, 18)),
    ('9#11', (0, 4, 7, 10, 14, 18)),
    ('m11', (0, 3, 7, 10, 14, 17)),    # https://chord-c.com/guitar-chord/B/minor-eleventh/
    ('13', (0, 4, 7, 10, 14, 21)),
    ('13-9', (0, 4, 7, 10, 13, 21)),
    ('13b9', (0, 4, 7, 10, 13, 21)),
    ('13+9', (0, 4, 7, 10, 15, 21)),
    ('13#9', (0, 4, 7, 10, 15, 21)),
    ('13+11', (0, 4, 7, 10, 18, 21)),
    ('13#11', (0, 4, 7, 10, 18, 21)),
    ('maj13', (0, 4, 7, 11, 14, 21)),   # https://chord-c.com/guitar-chord/C/major-thirteenth/
    ('M7add13', (0, 4, 7, 9, 11, 14))
]
